==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/CalendarFormatOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalendarFormatOptionsDescription } from "./CalendarFormatOptionsDescription";
/**
 * @hidden
 */
var CalendarFormatOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CalendarFormatOptionsDescriptionMetadata, _super);
    function CalendarFormatOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CalendarFormatOptionsDescriptionMetadata.b = function (a) {
        if (CalendarFormatOptionsDescriptionMetadata.a == null) {
            CalendarFormatOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CalendarFormatOptionsDescriptionMetadata.c(CalendarFormatOptionsDescriptionMetadata.a);
        }
        if (a.g(CalendarFormatOptionsDescriptionMetadata.a)) {
            return;
        }
        a.s(CalendarFormatOptionsDescriptionMetadata.a);
    };
    CalendarFormatOptionsDescriptionMetadata.c = function (a) {
        a.item("Weekday", "String");
        a.item("Month", "String");
    };
    CalendarFormatOptionsDescriptionMetadata.d = function (a) {
        CalendarFormatOptionsDescriptionMetadata.b(a);
        a.u("CalendarFormatOptions", function () { return new CalendarFormatOptionsDescription(); });
        a.t("CalendarFormatOptions", CalendarFormatOptionsDescriptionMetadata.a);
    };
    CalendarFormatOptionsDescriptionMetadata.$t = markType(CalendarFormatOptionsDescriptionMetadata, 'CalendarFormatOptionsDescriptionMetadata');
    CalendarFormatOptionsDescriptionMetadata.a = null;
    return CalendarFormatOptionsDescriptionMetadata;
}(Base));
export { CalendarFormatOptionsDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/CalendarFormatOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalendarFormatOptionsDescription } from "./CalendarFormatOptionsDescription";
/**
 * @hidden
 */
var CalendarFormatOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CalendarFormatOptionsDescriptionMetadata, _super);
    function CalendarFormatOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CalendarFormatOptionsDescriptionMetadata.b = function (a) {
        if (CalendarFormatOptionsDescriptionMetadata.a == null) {
            CalendarFormatOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CalendarFormatOptionsDescriptionMetadata.c(CalendarFormatOptionsDescriptionMetadata.a);
        }
        if (a.j(CalendarFormatOptionsDescriptionMetadata.a)) {
            return;
        }
        a.y(CalendarFormatOptionsDescriptionMetadata.a);
    };
    CalendarFormatOptionsDescriptionMetadata.c = function (a) {
        a.item("Weekday", "String");
        a.item("Month", "String");
    };
    CalendarFormatOptionsDescriptionMetadata.d = function (a) {
        CalendarFormatOptionsDescriptionMetadata.b(a);
        a.aa("CalendarFormatOptions", function () { return new CalendarFormatOptionsDescription(); });
        a.z("CalendarFormatOptions", CalendarFormatOptionsDescriptionMetadata.a);
    };
    CalendarFormatOptionsDescriptionMetadata.$t = markType(CalendarFormatOptionsDescriptionMetadata, 'CalendarFormatOptionsDescriptionMetadata');
    CalendarFormatOptionsDescriptionMetadata.a = null;
    return CalendarFormatOptionsDescriptionMetadata;
}(Base));
export { CalendarFormatOptionsDescriptionMetadata };
